@@ -5,11 +5,11 @@ class ModelInfo:
 
 	@classmethod
 	def table(cls):
-		raise NotImplemented()
+		raise NotImplementedError()
 
 	@classmethod
 	def fields(cls):
-		raise NotImplemented()
+		raise NotImplementedError()
 
 	def __init__(self, data: dict[str, Any]):
 		self.__dict__.update(data)
